@@ -13,7 +13,7 @@ use Exporter qw/ import /;
 our @EXPORT    = qw( conjunction );
 our @EXPORT_OK = @EXPORT;
 
-our $VERSION = 'v2.1.1';
+our $VERSION = 'v2.1.2';
 
 # Language-specific definitions (these may not be correct, and certainly
 # they are not complete... E-mail corrections and additions to the author
@@ -126,7 +126,7 @@ Lingua::Conjunction - Convert lists into simple linguistic conjunctions
 
 =head1 VERSION
 
-version v2.1.1
+version v2.1.2
 
 =head1 SYNOPSIS
 
@@ -198,7 +198,7 @@ languages, such as Norwegian. Hence the defaults set in the C<%languages>.
 C<Locale::Language>
 
 The I<Perl Cookbook> in Section 4.2 has a simular subroutine called
-C<commify_series>. The different is that 1. this routine handles
+C<commify_series>. The difference is that 1. this routine handles
 multiple languages and 2. being a module, you do not have to add
 the subroutine to a script every time you need it.
 
@@ -230,6 +230,12 @@ Damian Conway <damian@conway.org>
 
 =back
 
+=head1 CONTRIBUTOR
+
+=for stopwords Mohammad S Anwar
+
+Mohammad S Anwar <mohammad.anwar@yahoo.com>
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is Copyright (c) 2018 by Robert Rothenberg.
